@@ -2,13 +2,18 @@ reilly <-
 function (P_a, P_b, D_a, D_b, gamma = 1, lambda = 2, relation = NULL) 
 {
   
+  cat ("Reilly's Law of Retail Gravitation", "\n")
+  cat ("\n")
+  
   if (is.null(lambda))
   {
     if (is.null(relation)) { stop(paste("No relation stated", call. = FALSE)) }
     
     lambda <- log10(relation*(P_b/P_a))/log10(D_b/D_a)   
 
-    return(lambda)
+    cat(paste0("Lambda = ", lambda), "\n")
+    
+    invisible(lambda)
   }
   
   else
@@ -23,7 +28,10 @@ function (P_a, P_b, D_a, D_b, gamma = 1, lambda = 2, relation = NULL)
 
     results <- list(relation_AB = relation, prop_A = B_a, prop_B = B_b)   
 
-    return(results)   
+    cat("Results:", "\n")
+    print(as.data.frame(results))
+    
+    invisible(results)   
   }
   
 }
